pub struct CreateHistoryStreamIn {
pub id: String,
pub seq: Option<u64>,
pub live: Option<bool>,
pub keys: Option<bool>,
pub values: Option<bool>,
pub limit: Option<i64>,
}Fields
id: Stringseq: Option<u64>(number, default: 0): If seq > 0, then only stream messages with sequence numbers greater than seq.
live: Option<bool>live (boolean, default: false): Keep the stream open and emit new messages as they are received
keys: Option<bool>keys (boolean, default: true): whether the data event should contain keys. If set to true and values set to false then data events will simply be keys, rather than objects with a key property.
values: Option<bool>values (boolean, default: true): whether the data event should contain values. If set to true and keys set to false then data events will simply be values, rather than objects with a value property.
limit: Option<i64>limit (number, default: -1): limit the number of results collected by this stream. This number represents a maximum number of results and may not be reached if you get to the end of the data first. A value of -1 means there is no limit. When reverse=true the highest keys will be returned instead of the lowest keys.